#!/usr/bin/env python3
# Copyright (C) 2025 Spearhead Systems SRL

import copy
from cmk.base.plugins.agent_based.agent_based_api.v1 import State
from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    rulespec_registry,
    HostRulespec,
    CheckParameterRulespecWithItem,
    RulespecGroupCheckParametersNetworking,
)
from cmk.gui.watolib.rulespecs import Rulespec
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    ListOfStrings,
    DropdownChoice,
    Tuple,
    ListOf,
    TextInput
)


def _valuespec_special_agents_domains_nameservers_query():
    return Dictionary(
        title=_("Domains Nameservers Query"),
        required_keys=["domains"],
        elements=[
            (
                "domains",
                ListOfStrings(
                    title=_("Domain names"),
                    help=_("List of domain names to check"),
                    allow_empty=False,
                ),
            ),
        ]
    )

def _valuespec_special_agents_domains_nameservers_checks():
    return Dictionary(
        title=_("Domains Nameservers Checks"),
        required_keys=["domain_nameservers", "alert_level"],
        elements=[
            (
                "domain_nameservers",
                ListOf(
                    valuespec=Dictionary(
                        required_keys=["domains", "nameservers"],
                        elements=[
                            (
                                "domains",
                                ListOfStrings(
                                    title=_("Domain names"),
                                    help=_("List of domain names the below nameservers apply to"),
                                    allow_empty=False,
                                )
                            ),
                            (
                                "nameservers",
                                ListOfStrings(
                                    title=_("Nameservers"),
                                    help=_("List of nameservers that all of the above domain names should have"),
                                    allow_empty=False,
                                )
                            ),
                        ]
                    )
                )
            ),
            (
                "alert_level",
                DropdownChoice(
                    title=_("Alert level used on mismatch"),
                    help=_("Alert level used when there is a mismatch in domain name servers for a domain"),
                    default_value=State.WARN.value,
                    choices=[
                        (State.CRIT.value, _(State.CRIT.name)),
                        (State.WARN.value, _(State.WARN.name)),
                        (State.OK.value,   _(State.OK.name)),
                    ],
                ),
            ),
        ],
    )

rulespec_registry.register(
    HostRulespec(
        name="special_agents:domains_nameservers",
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        valuespec=_valuespec_special_agents_domains_nameservers_query,
    )
)
rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="domains_nameservers",
        group=RulespecGroupCheckParametersNetworking,
        match_type="dict",
        parameter_valuespec=_valuespec_special_agents_domains_nameservers_checks,
        item_spec=lambda: TextInput(title=_("Nameserver")),
        title=lambda: _("Domains Nameservers Checks"),
    )
)
